pub struct Sha256CompressionFunction(/* private fields */);Expand description
Circuit for the SHA-256 compression function.
Implementations
Sourceimpl Sha256CompressionFunction
impl Sha256CompressionFunction
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new Sha256CompressionFunction circuit.
Performance Note!
This involves parsing a Bristol Fashion file, and thus is not cheap!
Hence, it is best to reuse this circuit if possible versus calling
Sha256CompressionFunction::new every time this circuit is needed.