Sha256CompressionFunctionFixedIV

Struct Sha256CompressionFunctionFixedIV 

pub struct Sha256CompressionFunctionFixedIV(/* private fields */);
Circuit for the SHA-256 compression function, where the chaining values are fixed to the SHA-256 IV.

Implementations

Source

impl Sha256CompressionFunctionFixedIV

pub fn new() -> Self

Create a new Sha256CompressionFunctionFixedIV circuit.

Performance Note!

This involves parsing a Bristol Format file, and thus is not cheap! Hence, it is best to reuse this circuit if possible versus calling Sha256CompressionFunctionFixedIV::new every time this circuit is needed.